@@ -80,9 +80,9 @@ class Source :
 		self.add_fieldn('format')
 		self.add_fieldn('GLOBAL')  ## GLOBALINDEX
 		for v in "abcdefghijklmnopqrstuvwxyz": self.add_fieldn(v)
-		self.add_mf('MFN_Any_Any_', 'new_MethodField__1(ctx, KNH_FLAG_MF_VARARGS, TYPE_Any, TYPE_Any, FIELDN_o)')
-		self.add_mf('MFN_void_OutputStream_Any', 'new_MethodField__2(ctx, 0, TYPE_void, TYPE_OutputStream, FIELDN_w, TYPE_Any, FIELDN_o)')
-		self.add_mf('MFN_Any', 'new_MethodField__0(ctx, 0, TYPE_Any)')
+#		self.add_mf('MFN_Any_Any_', 'new_MethodField__1(ctx, KNH_FLAG_MF_VARARGS, TYPE_Any, TYPE_Any, FIELDN_o)')
+#		self.add_mf('MFN_void_OutputStream_Any', 'new_MethodField__2(ctx, 0, TYPE_void, TYPE_OutputStream, FIELDN_w, TYPE_Any, FIELDN_o)')
+#		self.add_mf('MFN_Any', 'new_MethodField__0(ctx, 0, TYPE_Any)')
 	###
 	
 	def kpath2(self, fpath):
@@ -483,7 +483,7 @@ class Expt :
 ## parser
 
 def functype_filter(text):
-	text = text.replace('PUBLIC', '').replace('_SS_', '').replace('INLINE','')
+	text = text.replace('', '').replace('_SS_', '').replace('','')
 	prev = ' '
 	text2 = ''
 	for c in text:
