@@ -573,7 +573,7 @@ knh_uint64_t knh_timecount();
 /* ../src/konoha.c */
 int main(int argc, char **argv);
 /* ../src/labs/b4.c */
-void konoha_initfibo(Ctx *ctx);
+METHOD knh__Script_initfibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_fibo(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_changeChannel(Ctx *ctx, knh_sfp_t *sfp);
 METHOD knh__Script_hook(Ctx *ctx, knh_sfp_t *sfp);
@@ -637,6 +637,7 @@ void knh_Object_free(Ctx *ctx, knh_Object_t *o);
 void knh_Object_traverse(Ctx *ctx, knh_Object_t *o, knh_ftraverse ftr);
 void knh_Object_mark1(Ctx *ctx, Object *o);
 METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp);
+void knh_System_gc(Ctx *ctx);
 void knh_Object_RCsweep(Ctx *ctx, Object *o);
 knh_ftraverse konoha_getDefaultSweepFunc();
 /* ../src/main/stack.c */
