@@ -105,27 +105,27 @@ knh_code_t* KNH_ASM_fnCAST_(Ctx *ctx, Asm *o,knh_sfi_t a1);
 knh_code_t* KNH_ASM_bNOT_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2);
 knh_code_t* KNH_ASM_iNEG_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2);
 knh_code_t* KNH_ASM_iADD_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iADDn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iADDn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iSUB_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iSUBn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iSUBn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iMUL_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iMULn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iMULn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iDIV_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iDIVn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iDIVn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iMOD_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iMODn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iMODn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iEQ_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iEQn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iEQn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iNEQ_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iNEQn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iNEQn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iLT_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iLTn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iLTn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iLTE_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iLTEn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iLTEn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iGT_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iGTn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iGTn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_iGTE_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
-knh_code_t* KNH_ASM_iGTEn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_integer_t a3);
+knh_code_t* KNH_ASM_iGTEn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_int_t a3);
 knh_code_t* KNH_ASM_fNEG_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2);
 knh_code_t* KNH_ASM_fADD_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_sfi_t a3);
 knh_code_t* KNH_ASM_fADDn_(Ctx *ctx, Asm *o,knh_sfi_t a1,knh_sfi_t a2,knh_float_t a3);
@@ -1138,7 +1138,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_iaddn_t;
 
@@ -1166,7 +1166,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_isubn_t;
 
@@ -1194,7 +1194,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_imuln_t;
 
@@ -1222,7 +1222,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_idivn_t;
 
@@ -1250,7 +1250,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_imodn_t;
 
@@ -1278,7 +1278,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_ieqn_t;
 
@@ -1306,7 +1306,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_ineqn_t;
 
@@ -1334,7 +1334,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_iltn_t;
 
@@ -1362,7 +1362,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_ilten_t;
 
@@ -1390,7 +1390,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_igtn_t;
 
@@ -1418,7 +1418,7 @@ typedef struct {
 	knh_opcode_t opcode;
 	knh_sfi_t a1;
 	knh_sfi_t a2;
-	knh_integer_t a3;
+	knh_int_t a3;
 	void *nextaddr;
 } klr_igten_t;
 
