@@ -638,7 +638,7 @@ static knh_ClassData_t ClassData[] = {
 	{"konoha.ResultSet", CLASS_ResultSet, CFLAG_ResultSet, STRUCT_ResultSet, CLASS_Object, 0, 9, 0, knh_ResultSet_fdefault},
 	{"konoha.Exception", CLASS_Exception, CFLAG_Exception, STRUCT_Exception, CLASS_Object, 0, 9, 0, knh_Exception_fdefault},
 	{"konoha.ExceptionHandler", CLASS_ExceptionHandler, CFLAG_ExceptionHandler, STRUCT_ExceptionHandler, CLASS_Object, 0, 0, 0, knh_ExceptionHandler_fdefault},
-	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 9, 0, knh_Script_fdefault},
+	{"konoha.Script", CLASS_Script, CFLAG_Script, STRUCT_Script, CLASS_Object, 0, 10, 0, knh_Script_fdefault},
 	{"konoha.NameSpace", CLASS_NameSpace, CFLAG_NameSpace, STRUCT_NameSpace, CLASS_Object, 0, 0, 0, knh_NameSpace_fdefault},
 	{"konoha.System", CLASS_System, CFLAG_System, STRUCT_System, CLASS_Object, 0, 14, 0, knh_System_fdefault},
 	{"konoha.Context", CLASS_Context, CFLAG_Context, STRUCT_Context, CLASS_Object, 0, 16, 0, knh_Context_fdefault},
@@ -748,6 +748,7 @@ static knh_FieldNameData_t FieldNameData[] = {
 	{"index", FIELDN_index},
 	{"indexOf", FIELDN_indexOf},
 	{"init", FIELDN_init},
+	{"initfibo", FIELDN_initfibo},
 	{"insert", FIELDN_insert},
 	{"int", FIELDN_int},
 	{"invoke", FIELDN_invoke},
@@ -1317,6 +1318,7 @@ static knh_MethodData_t MethodData[] = {
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__s, 0, MFN_void_OutputStream_Any, (void*)knh_Token__s},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__k, 0, MFN_void_OutputStream_Any, (void*)knh_Token__k},
 	{knh_fmethod_movableText, 0, CLASS_Token, METHODN__dump, 0, MFN_void_OutputStream_Any, (void*)knh_Token__dump},
+	{knh__Script_initfibo, 0, CLASS_Script, METHODN_initfibo, 0, MFN_nInt, (void*)NULL},
 	{knh__Script_fibo, 0, CLASS_Script, METHODN_fibo, 0, MFN_nInt_nInt, (void*)NULL},
 	{knh__Script_changeChannel, 0, CLASS_Script, METHODN_changeChannel, 0, MFN_void_nInt, (void*)NULL},
 	{knh__Script_hook, 0, CLASS_Script, METHODN_hook, 0, MFN_void_nString, (void*)NULL},
