@@ -39,7 +39,7 @@
 #else
 #define KONOHA_NAME     "konoha"
 #define KONOHA_MAJOR_VERSION "0.3"
-#define KONOHA_VERSION  "0.3.6"
+#define KONOHA_VERSION  "0.3.7"
 #endif
 
 #define KONOHA_URL		"http://konoha.sourceforge.jp/"
@@ -79,7 +79,7 @@
 /* ======================================================================== */
 /* [OPTIONS] */
 
-#define KNH_USING_RCGC    1                /* Reference Counting */
+//#define KNH_USING_RCGC    1                /* Reference Counting */
 //#define KNH_USING_DRCGC   1
 
 /* ======================================================================== */
