@@ -118,7 +118,14 @@
 #else/*KNH_DBGMODE*/
 
 #define DBG_(stmt)
-#define DBG_P(fmt, ...)
+#define DBG_P(fmt, ...) \
+	if(konoha_isDebugMode()) {\
+		fflush(stdout); \
+		fprintf(stderr, "DBG[%s:%d/%s]: ", KNH_SAFEFILE(__FILE__), __LINE__, __FUNCTION__); \
+		fprintf(stderr, fmt, ## __VA_ARGS__); \
+		fprintf(stderr, "\n"); \
+	}\
+
 #define DBG_DUMP(ctx, o, opt, msg)
 #define TODO()
 #define DBG_ASSERT(c, fmt, ...)   KNH_ASSERT(c)
