@@ -47,7 +47,7 @@ knh_hcode_t knh_stack_hashCode(Ctx *ctx, knh_sfp_t *sfp)
 	if(CLASS_Boolean <= bcid && bcid <= CLASS_Float) {
 		return (knh_hcode_t)(sfp[0].i)->n.data;
 	}
-	return ctx->tStruct[bcid].fhashCode(ctx, sfp[0].o);
+	return ctx->share->StructTable[bcid].fhashCode(ctx, sfp[0].o);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -70,7 +70,7 @@ static METHOD knh__HashMap_new(Ctx *ctx, knh_sfp_t *sfp)
 	HashMap *o = (HashMap*)sfp[0].o;
 	int init = IS_NULL(sfp[1].o) ? KNH_HASH_INITSIZE: p_int(sfp[1]);
 	if(init > 0) {
-		ctx->tStruct[STRUCT_HashMap].finit(ctx, sfp[0].o, init);
+		ctx->share->StructTable[STRUCT_HashMap].finit(ctx, sfp[0].o, init);
 	}
 	KNH_RETURN(ctx, sfp, o);
 }
@@ -82,7 +82,7 @@ static METHOD knh__HashMap_get(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
-	knh_uint_t h =  hcode % DP(o)->hmax;
+	knh_uintptr_t h =  hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 
 	while(e != NULL) {
@@ -103,7 +103,7 @@ static METHOD knh__HashMap_opHas(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
-	knh_uint_t h =  hcode % DP(o)->hmax;
+	knh_uintptr_t h =  hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 
 	while(e != NULL) {
@@ -125,7 +125,7 @@ static METHOD knh__HashMap_remove(Ctx *ctx, knh_sfp_t *sfp)
 	KNH_CHECK_IMMUTABLE(ctx, sfp[0].o, L_RETURN);
 	knh_Hash_t *o = (knh_Hash_t*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
-	knh_uint_t h =  hcode % DP(o)->hmax;
+	knh_uintptr_t h =  hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 	knh_hashentry_t **prev_next = &(DP(o)->array[h]);
 
@@ -157,7 +157,7 @@ static METHOD knh__HashMap_set(Ctx *ctx, knh_sfp_t *sfp)
 
 	knh_Hash_t *o = (knh_Hash_t*)sfp[0].o;
 	knh_hcode_t hcode = knh_stack_hashCode(ctx, sfp + 1);
-	knh_uint_t h =  hcode % DP(o)->hmax;
+	knh_uintptr_t h =  hcode % DP(o)->hmax;
 	knh_hashentry_t *e = DP(o)->array[h];
 
 	while(e != NULL) {
@@ -247,7 +247,7 @@ ITRNEXT knh_HashMap_var_next(Ctx *ctx, knh_sfp_t *sfp, int n)
 MAPPER knh_HashMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
-	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, ctx->tClass[o->h.cid].p1, UP(o), knh_HashMap_var_next));
+	KNH_MAPPED(ctx, sfp, new_Iterator(ctx, ctx->share->ClassTable[o->h.cid].p1, UP(o), knh_HashMap_var_next));
 }
 
 /* ------------------------------------------------------------------------ */
@@ -256,7 +256,7 @@ MAPPER knh_HashMap_Iterator(Ctx *ctx, knh_sfp_t *sfp)
 static METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 {
 	HashMap *o = (HashMap*)sfp[0].o;
-	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->tClass[o->h.cid].p1, UP(o), knh_HashMap_var_next));
+	KNH_RETURN(ctx, sfp, new_Iterator(ctx, ctx->share->ClassTable[o->h.cid].p1, UP(o), knh_HashMap_var_next));
 }
 
 ///* ------------------------------------------------------------------------ */
@@ -309,7 +309,7 @@ static METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 ///* ------------------------------------------------------------------------ */
 ///* @method Boolean HashSet.opHas(Any1 key) */
 //
-//INLINE
+//
 //knh_bool_t knh_HashSet_opHas(Ctx *ctx, HashSet *b, knh_hcode_t key, Object *keyobj)
 //{
 //	return (knh_HashSet_get(ctx, b, key, keyobj) != 0);
@@ -324,7 +324,7 @@ static METHOD knh__HashMap_opItr(Ctx *ctx, knh_sfp_t *sfp)
 //
 //Iterator* knh_HashSet_Iterator(Ctx *ctx, HashSet *o, Mapper *map)
 //{
-//	return new_Iterator(ctx, ctx->tClass[o->h.cid].p1, o, knh_HashMap_key_next);
+//	return new_Iterator(ctx, ctx->share->ClassTable[o->h.cid].p1, o, knh_HashMap_key_next);
 //}
 //
 ///* ======================================================================== */
