@@ -70,7 +70,7 @@ static METHOD knh__Object_new__init(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp)
 {
-	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx,  sfp[0].o, sfp[1].o) == 0);
+	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) == 0);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -78,7 +78,7 @@ static METHOD knh__Object_opEq(Ctx *ctx, knh_sfp_t *sfp)
 
 static METHOD knh__Object_opNeq(Ctx *ctx, knh_sfp_t *sfp)
 {
-	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx,  sfp[0].o, sfp[1].o) != 0);
+	KNH_RETURN_Boolean(ctx, sfp, knh_Object_compareTo(ctx, sfp[0].o, sfp[1].o) != 0);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -170,11 +170,11 @@ static METHOD knh__Object_opTo(Ctx *ctx, knh_sfp_t *sfp)
 }
 
 /* ------------------------------------------------------------------------ */
-/* @method[CONST] Class! Object.getClass() */
+/* @method[CONST] Class! Object.geClassTable() */
 
-static METHOD knh__Object_getClass(Ctx *ctx, knh_sfp_t *sfp)
+static METHOD knh__Object_geClassTable(Ctx *ctx, knh_sfp_t *sfp)
 {
-	KNH_RETURN(ctx, sfp, ctx->tClass[(sfp[0].o)->h.cid].class_cid);
+	KNH_RETURN(ctx, sfp, ctx->share->ClassTable[(sfp[0].o)->h.cid].class_cid);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -233,7 +233,7 @@ static
 void knh_Object__k(Ctx *ctx, Object *o, OutputStream *w, String *m)
 {
 	if(o->h.bcid == CLASS_Object) {
-		size_t bsize = ctx->tClass[o->h.cid].bsize;
+		size_t bsize = ctx->share->ClassTable[o->h.cid].bsize;
 		knh_write__s(ctx, w, CLASSN(o->h.cid));
 		if(bsize > 0) {
 			size_t i;
@@ -266,9 +266,9 @@ void knh_Object__dump(Ctx *ctx, Object *b, OutputStream *w, String *m)
 		knh_format(ctx, w, METHODN__s, b, KNH_NULL);
 		return ;
 	}
-	knh_int_t i, c = 0;
+	knh_intptr_t i, c = 0;
 	knh_putc(ctx, w, '[');
-	for(i = 0; i < ctx->tClass[cid].bsize; i++) {
+	for(i = 0; i < ctx->share->ClassTable[cid].bsize; i++) {
 		knh_cfield_t *cf = knh_Class_fieldAt(ctx, cid, i);
 		if(cf->fn == FIELDN_NONAME || KNH_FLAG_IS(cf->flag, KNH_FLAG_CFF_HIDDEN)) continue;
 		if(c > 0) {
@@ -311,7 +311,7 @@ static
 MAPPER knh_Object_String(Ctx *ctx, knh_sfp_t *sfp)
 {
 	Object *o = sfp[0].o;
-	Method *mtd = knh_tMethod_findMT(ctx, knh_Object_cid(o), METHODN__s);
+	Method *mtd = konoha_lookupFormatter(ctx, knh_Object_cid(o), METHODN__s);
 	if(IS_NULL(mtd)) {
 		KNH_MAPPED(ctx, sfp, TS_EMPTY);
 	}
@@ -437,14 +437,14 @@ void knh_Class_NAME__man(Ctx *ctx, knh_class_t cid, OutputStream *w)
 	knh_write_EOL(ctx, w);
 
 	knh_write_TAB(ctx, w);
-	knh_write(ctx, w, knh_String_tobytes(ctx->tClass[cid].lname));
+	knh_write(ctx, w, knh_String_tobytes(ctx->share->ClassTable[cid].lname));
 	knh_write_EOL(ctx, w);
 
-	while(ctx->tClass[cid].supcid != CLASS_Object) {
-		cid = ctx->tClass[cid].supcid;
+	while(ctx->share->ClassTable[cid].supcid != CLASS_Object) {
+		cid = ctx->share->ClassTable[cid].supcid;
 		knh_write_TAB(ctx, w);
 		knh_write(ctx, w, STEXT("extends "));
-		knh_write(ctx, w, knh_String_tobytes(ctx->tClass[cid].lname));
+		knh_write(ctx, w, knh_String_tobytes(ctx->share->ClassTable[cid].lname));
 		knh_write_EOL(ctx, w);
 	}
 }
@@ -478,7 +478,7 @@ void knh_Method__man(Ctx *ctx, Method *o, OutputStream *w, knh_class_t cid)
 		if(i > 0) {
 			knh_write_delim(ctx, w);
 		}
-		knh_mfield_t mf = knh_Method_pfield(o, i);
+		knh_mparam_t mf = knh_Method_param(o, i);
 		knh_write_type(ctx, w, knh_pmztype_totype(ctx, mf.type, cid));
 		knh_putc(ctx, w, ' ');
 		knh_write(ctx, w, B(FIELDN(mf.fn)));
@@ -507,7 +507,7 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 	KNH_LPUSH(ctx, dm);
 	size_t i = 0;
 	while(1) {
-		Array *a = ctx->tClass[cid].cstruct->methods;
+		Array *a = ctx->share->ClassTable[cid].cstruct->methods;
 		for(i = 0; i < knh_Array_size(a); i++) {
 			Method *mtd = (Method*)knh_Array_n(a, i);
 			char *op = knh_methodop_tochar(DP(mtd)->mn);
@@ -527,7 +527,7 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 			}
 		}
 		if(cid == CLASS_Object) break;
-		cid = ctx->tClass[cid].supcid;
+		cid = ctx->share->ClassTable[cid].supcid;
 	}
 
 	int cnt = 0;
@@ -573,7 +573,7 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 		if(IS_Method(mtd)) {
 			if(METHODN_IS_MOVTEXT(DP(mtd)->mn)) continue;
 			if(DP(mtd)->cid == CLASS_Object && cid != CLASS_Object) continue;
-//			if(DP(mtd)->cid != ctx->tClass[cid].bcid) continue;
+//			if(DP(mtd)->cid != ctx->share->ClassTable[cid].bcid) continue;
 			if(hasCaption == 0) {
 				knh_write__s(ctx, w, knh_message_text(KMSG_METHOD));
 				knh_write_EOL(ctx, w);
@@ -611,7 +611,7 @@ void knh_Class__man(Ctx *ctx, Class *o, OutputStream *w, String *m)
 	}
 	knh_write_EOL(ctx, w);
 
-	knh_ClassMap__man(ctx, ctx->tClass[cid].cmap, w, cid);
+	knh_ClassMap__man(ctx, ctx->share->ClassTable[cid].cmap, w, cid);
 	KNH_LOCALBACK(ctx, lsfp);
 }
 
@@ -651,7 +651,7 @@ void knh_Method__k(Ctx *ctx, Method *o, OutputStream *w, String *m)
 		if(i > 0) {
 			knh_write_delim(ctx, w);
 		}
-		knh_mfield_t mf = knh_Method_pfield(o, i);
+		knh_mparam_t mf = knh_Method_param(o, i);
 		//knh_write__type(ctx, w, knh_pmztype_totype(ctx, mf.type, DP(o)->cid));
 		knh_write_type(ctx, w, mf.type);
 		knh_putc(ctx, w, ' ');
