@@ -50,54 +50,54 @@ extern "C" {
 #endif
 
 /* ======================================================================== */
-/* [tExpt] */
+/* [ExptTable] */
 
 static
-knh_class_t knh_tExpt_newId(Ctx *ctx)
+knh_class_t knh_ExptTable_newId(Ctx *ctx)
 {
 	knh_class_t newid;
-	KNH_LOCK(ctx, ctx->tableLock);
-	if(!(ctx->share->tExptSize < KNH_TEXPT_SIZE)) {
-		KNH_UNLOCK(ctx, ctx->tableLock);
+	KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+	if(!(ctx->share->ExptTableSize < KNH_TEXPT_SIZE)) {
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 		KNH_EXIT("Enlarge KNH_TEXPT_SIZE %d", KNH_TEXPT_SIZE);
 		return 0;
 	}
-	newid = ctx->share->tExptSize;
-	ctx->share->tExptSize += 1;
-	KNH_UNLOCK(ctx, ctx->tableLock);
+	newid = ctx->share->ExptTableSize;
+	ctx->share->ExptTableSize += 1;
+	KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
 	return newid + 1;
 }
 
-#define _KNH_ASSERT_eid(eid)    KNH_ASSERT(eid < ctx->share->tExptSize + 1)
+#define _KNH_ASSERT_eid(eid)    KNH_ASSERT(eid < ctx->share->ExptTableSize + 1)
 
 ///* ------------------------------------------------------------------------ */
 //
 //static
-//knh_flag_t knh_tExpt_flag(Ctx *ctx, knh_expt_t eid)
+//knh_flag_t knh_ExptTable_flag(Ctx *ctx, knh_expt_t eid)
 //{
 //	KNH_ASSERT_eid(eid);
-//	return (ctx)->tExpt[eid-1].flag;
+//	return ctx->share->ExptTable[eid-1].flag;
 //}
 //
 ///* ------------------------------------------------------------------------ */
 //
 //static
-//knh_expt_t knh_tExpt_parent(Ctx *ctx, knh_expt_t eid)
+//knh_expt_t knh_ExptTable_parent(Ctx *ctx, knh_expt_t eid)
 //{
 //	KNH_ASSERT_eid(eid);
-//	return (ctx)->tExpt[eid-1].parent;
+//	return ctx->share->ExptTable[eid-1].parent;
 //}
 
 /* ------------------------------------------------------------------------ */
 
 static
-int knh_tExpt_isa(Ctx *ctx, knh_expt_t eid, knh_expt_t parent)
+int knh_ExptTable_isa(Ctx *ctx, knh_expt_t eid, knh_expt_t parent)
 {
 	KNH_ASSERT_eid(eid);
-	KNH_ASSERT(parent < ctx->share->tExptSize);
+	KNH_ASSERT(parent < ctx->share->ExptTableSize);
 	if(eid == parent || parent == 1) return 1;
 	if(eid == 1) return 0;
-	while((eid = (ctx)->tExpt[eid-1].parent) != 1) {
+	while((eid = ctx->share->ExptTable[eid-1].parent) != 1) {
 		if(eid == parent) return 1;
 	}
 	return 0;
@@ -105,12 +105,12 @@ int knh_tExpt_isa(Ctx *ctx, knh_expt_t eid, knh_expt_t parent)
 
 /* ------------------------------------------------------------------------ */
 
-#define _EXPTN(eid)   knh_String_tochar(knh_tExpt_name(ctx, eid))
+#define _EXPTN(eid)   knh_String_tochar(knh_ExptTable_name(ctx, eid))
 
-String *knh_tExpt_name(Ctx *ctx, knh_expt_t eid)
+String *knh_ExptTable_name(Ctx *ctx, knh_expt_t eid)
 {
 	KNH_ASSERT_eid(eid);
-	return (ctx)->tExpt[eid-1].name;
+	return ctx->share->ExptTable[eid-1].name;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -119,7 +119,7 @@ String *knh_tExpt_name(Ctx *ctx, knh_expt_t eid)
 static
 knh_expt_t knh_texpt_forname(Ctx *ctx, knh_bytes_t msg, knh_expt_t def)
 {
-	knh_int_t loc = knh_bytes_index(msg, '!');
+	knh_intptr_t loc = knh_bytes_index(msg, '!');
 	if(loc != -1) {
 		if(msg.buf[loc+1] != '!') {
 			return EXPT_Exception;
@@ -129,7 +129,7 @@ knh_expt_t knh_texpt_forname(Ctx *ctx, knh_bytes_t msg, knh_expt_t def)
 
 	if(msg.len == 0) return EXPT_Exception; /* '!!' */
 
-	knh_expt_t eid = (knh_expt_t)knh_DictSet_get__b(DP(ctx->sys)->texptNameDictSet, msg);
+	knh_expt_t eid = (knh_expt_t)knh_DictSet_get__b(DP(ctx->sys)->ExptNameDictSet, msg);
 	if(eid != 0) return eid;
 	if(def == EXPT_newid) {
 		return konoha_addException(ctx, KNH_FLAG_EF_GENERATED, EXPT_newid, new_String(ctx, msg, NULL), NULL);
@@ -144,10 +144,10 @@ knh_expt_t
 konoha_addException(Ctx *ctx, knh_flag_t flag, knh_class_t eid, String *name, char *pname)
 {
 	if(eid == EXPT_newid) {
-		eid = knh_tExpt_newId(ctx);
+		eid = knh_ExptTable_newId(ctx);
 	}else {
-		ctx->share->tExptSize += 1;
-		KNH_ASSERT(eid == ctx->share->tExptSize);
+		ctx->share->ExptTableSize += 1;
+		KNH_ASSERT(eid == ctx->share->ExptTableSize);
 	}
 
 	KNH_ASSERT_eid(eid);
@@ -160,12 +160,12 @@ konoha_addException(Ctx *ctx, knh_flag_t flag, knh_class_t eid, String *name, ch
 		}
 	}
 
-	KNH_ASSERT(((Context*)ctx)->tExpt[eid-1].name == NULL);
-	((Context*)ctx)->tExpt[eid-1].flag = flag;
-	((Context*)ctx)->tExpt[eid-1].parent = parent;
-	KNH_INITv(((Context*)ctx)->tExpt[eid-1].name, name);
-	knh_DictSet_set(ctx, DP(ctx->sys)->texptNameDictSet, name, eid);
-	//DBG2_P("Generating new Exception eid=%d name='%s'", eid, knh_String_tochar(((Context*)ctx)->tExpt[eid].name));
+	KNH_ASSERT(ctx->share->ExptTable[eid-1].name == NULL);
+	ctx->share->ExptTable[eid-1].flag = flag;
+	ctx->share->ExptTable[eid-1].parent = parent;
+	KNH_INITv(ctx->share->ExptTable[eid-1].name, name);
+	knh_DictSet_set(ctx, DP(ctx->sys)->ExptNameDictSet, name, eid);
+	//DBG2_P("Generating new Exception eid=%d name='%s'", eid, knh_String_tochar(((Context*)ctx)->ExptTable[eid].name));
 	return eid;
 }
 
@@ -191,7 +191,7 @@ Exception* knh_Exception_new__init(Ctx *ctx, Exception *o, String *e, String *ms
 		DP(o)->eid = eid;
 	}
 	KNH_ASSERT_eid(eid);
-	DP(o)->flag = ctx->tExpt[DP(o)->eid].flag;
+	DP(o)->flag = ctx->share->ExptTable[DP(o)->eid].flag;
 	{
 		if(IS_NOTNULL(msg)) {
 			KNH_RCSETv(ctx, DP(o)->bag, msg);
@@ -227,7 +227,7 @@ int knh_Exception_isa(Ctx *ctx, Exception *o, String *msg)
 {
 	knh_expt_t eid = knh_texpt_forname(ctx, knh_String_tobytes(msg), EXPT_unknown);
 	if(eid == EXPT_unknown) return 0;
-	return knh_tExpt_isa(ctx, DP(o)->eid, eid);
+	return knh_ExptTable_isa(ctx, DP(o)->eid, eid);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -297,7 +297,7 @@ KNHAPI(void) knh_perrno(Ctx *ctx, char *emsg, char *func, char *file, int line)
 
 /* ------------------------------------------------------------------------ */
 
-KNHAPI(void) knh_throw_OutOfIndex(Ctx *ctx, knh_integer_t n, size_t max, char *file, int line)
+KNHAPI(void) knh_throw_OutOfIndex(Ctx *ctx, knh_int_t n, size_t max, char *file, int line)
 {
 	char buf[80];
 	knh_snprintf(buf, sizeof(buf), "OutOfIndex!!: %d <%d", (int)n, (int)max);
