@@ -88,7 +88,7 @@ StringUnit *new_StringUnit(Ctx *ctx, knh_flag_t flag, knh_class_t cid, String *t
 static
 String *knh_fvcabnew__dict(Ctx *ctx, knh_class_t cid, knh_bytes_t t, String *orign)
 {
-	StringUnit *u = (StringUnit*)ctx->tClass[cid].cspec;
+	StringUnit *u = (StringUnit*)ctx->share->ClassTable[cid].cspec;
 	KNH_ASSERT(IS_StringUnit(u));
 	knh_index_t n = knh_DictIdx_index(ctx, DP(u)->vocabDictIdx, t);
 	if(n == -1) return new_StringX__FormatException(ctx, cid, t, orign);
@@ -128,7 +128,7 @@ int knh_fvcabcmp__dict(StringUnit *o, knh_bytes_t v1, knh_bytes_t v2)
 
 KNHAPI(ClassSpec*) new_Vocabulary(Ctx *ctx, char *lang, char *defval, ...)
 {
-	knh_class_t cid = knh_tClass_newId(ctx);
+	knh_class_t cid = knh_ClassTable_newId(ctx);
 	StringUnit* o = new_StringUnit(ctx, 0, cid, TS_EMPTY);
 
 	DP(o)->fbconv = NULL;
@@ -159,11 +159,11 @@ static
 MAPPER knh_Mapper_fvocab(Ctx *ctx, knh_sfp_t *sfp)
 {
 	String *s = sfp[0].s;
-	StringUnit *u = (StringUnit*)ctx->tClass[knh_Object_cid(sfp[0].o)].cspec;
+	StringUnit *u = (StringUnit*)ctx->share->ClassTable[knh_Object_cid(sfp[0].o)].cspec;
 	KNH_ASSERT(IS_StringUnit(u));
 	KNH_ASSERT(IS_DictIdx(DP(u)->vocabDictIdx));
 
-	StringUnit *u2 = (StringUnit*)ctx->tClass[DP(sfp[1].mpr)->tcid].cspec;
+	StringUnit *u2 = (StringUnit*)ctx->share->ClassTable[DP(sfp[1].mpr)->tcid].cspec;
 	KNH_ASSERT(IS_StringUnit(u2));
 	KNH_ASSERT(IS_DictIdx(DP(u2)->vocabDictIdx));
 
@@ -179,13 +179,13 @@ KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text)
 	KNH_ASSERT_cid(scid);
 	knh_class_t tcid = konoha_findcid(ctx, B(text));
 
-	if(tcid != CLASS_unknown || ctx->tClass[tcid].bcid != tcid) {
-//		StringUnit *u = (StringUnit*)ctx->tClass[scid].cspec;
+	if(tcid != CLASS_unknown || ctx->share->ClassTable[tcid].bcid != tcid) {
+//		StringUnit *u = (StringUnit*)ctx->share->ClassTable[scid].cspec;
 //		if(!IS_StringUnit(u) || !IS_DictIdx(DP(u)->vocabDictIdx)) {
 //			TODO();
 //			return;
 //		}
-		StringUnit *u2 = (StringUnit*)ctx->tClass[tcid].cspec;
+		StringUnit *u2 = (StringUnit*)ctx->share->ClassTable[tcid].cspec;
 		if(!IS_StringUnit(u2) || !IS_DictIdx(DP(u2)->vocabDictIdx)) {
 			TODO();
 			return;
@@ -196,19 +196,19 @@ KNHAPI(void) konoha_addVocabularyMapper(Ctx *ctx, knh_class_t scid, char *text)
 //		}
 		Mapper *mpr = new_Mapper(ctx, KNH_FLAG_MMF_AFFINE, scid, tcid,
 				knh_Mapper_fvocab, (Object*)KNH_NULL);
-		if(ctx->tClass[scid].cmap == NULL) {
-			knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[scid]);
+		if(ctx->share->ClassTable[scid].cmap == NULL) {
+			knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[scid]);
 			KNH_INITv(TC->cmap, new_ClassMap0(ctx, 4));
 		}
-		knh_ClassMap_add(ctx, ctx->tClass[scid].cmap, mpr);
+		knh_ClassMap_add(ctx, ctx->share->ClassTable[scid].cmap, mpr);
 
 		mpr = new_Mapper(ctx, KNH_FLAG_MMF_AFFINE, tcid, scid,
 				knh_Mapper_fvocab, (Object*)KNH_NULL);
-		if(ctx->tClass[tcid].cmap == NULL) {
-			knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[tcid]);
+		if(ctx->share->ClassTable[tcid].cmap == NULL) {
+			knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[tcid]);
 			KNH_INITv(TC->cmap, new_ClassMap0(ctx, 4));
 		}
-		knh_ClassMap_add(ctx, ctx->tClass[tcid].cmap, mpr);
+		knh_ClassMap_add(ctx, ctx->share->ClassTable[tcid].cmap, mpr);
 	}
 }
 
