@@ -130,7 +130,7 @@ knh_type_t knh_Token_gettype(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t defc
 			cid = CLASS_Exception;
 		}
 		else {
-			cid = knh_NameSpace_getClass(ctx, ns, name);
+			cid = knh_NameSpace_geClassTable(ctx, ns, name);
 			if(cid == CLASS_unknown) {
 				cid = defc;
 				knh_Token_perror(ctx, o, KMSG_UCLASSN);
@@ -166,7 +166,7 @@ knh_class_t knh_Token_getcid(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t defc
 			return CLASS_Exception;
 		}
 		knh_bytes_t name = knh_Token_tobytes(ctx, o);
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, name);
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, name);
 		if(cid == CLASS_unknown) {
 
 			if(defc == CLASS_unknown) {
@@ -317,7 +317,7 @@ int knh_Token_toSYSVAL(Ctx *ctx, Token *tk, Asm *abr)
 		return 1;
 	}
 	else if(IS_SYSVAL(t, "__method__") || IS_SYSVAL(t, "__function__")) {
-		knh_Token_setCONST(ctx, tk, UP(knh_Method_getURN(ctx, DP(abr)->mtd)));
+		knh_Token_setCONST(ctx, tk, UP(knh_Object_getkey(ctx, UP(DP(abr)->mtd))));
 		return 1;
 	}
 	else if(IS_SYSVAL(t, "__namespace__") || IS_SYSVAL(t, "__ns__")) {
@@ -423,7 +423,7 @@ int knh_Asm_declareScriptVariable(Ctx *ctx, Asm *abr, knh_flag_t flag, knh_type_
 {
 	knh_Script_t *scr = knh_Asm_getScript(ctx, abr);
 	knh_class_t cid = knh_Object_cid(scr);
-	knh_cfield_t *cf = (ctx->tClass[cid].cstruct)->fields;
+	knh_cfield_t *cf = (ctx->share->ClassTable[cid].cstruct)->fields;
 	knh_index_t idx = knh_Asm_addVariableTable(ctx, abr, cf, KNH_SCRIPT_FIELDSIZE, flag, type, fn, value);
 	if(idx != -1) {
 		KNH_SETv(ctx, scr->fields[idx], value);
@@ -559,7 +559,7 @@ int knh_TokenCONSTN_typing(Ctx *ctx, Token *o, Asm *abr, NameSpace *ns)
 		}
 	}
 	else {
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, knh_bytes_first(t, loc));
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, knh_bytes_first(t, loc));
 		if(cid != CLASS_unknown) {
 			char buf[CLASSNAME_BUFSIZ*2];
 			knh_snprintf(buf, sizeof(buf), "%s.%s", CLASSN(cid), &t.buf[loc+1]);
@@ -594,7 +594,7 @@ void knh_Token_toCLASSID(Ctx *ctx, Token *o, knh_class_t cid)
 	SP(o)->tt = TT_CLASSID;
 	DP(o)->cid = cid;
 	DP(o)->type = NNTYPE_Class;
-	KNH_SETv(ctx, DP(o)->data, ctx->tClass[cid].class_cid);
+	KNH_SETv(ctx, DP(o)->data, ctx->share->ClassTable[cid].class_cid);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -629,7 +629,7 @@ int knh_TokenCMETHODN_typing(Ctx *ctx, Token *o, NameSpace *ns)
 	if(idx == -1) return 0;
 
 	knh_bytes_t cname = knh_bytes_first(t, idx);
-	knh_class_t cid = knh_NameSpace_getClass(ctx, ns, cname);
+	knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, cname);
 	if(cid == CLASS_unknown) {
 		knh_Token_perror(ctx, o, KMSG_UCLASSN);
 		return 0;
@@ -751,7 +751,7 @@ int knh_TokenNUM_typing(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t reqc)
 		return 1;
 	}
 
-	knh_class_t req_bcid = ctx->tClass[reqc].bcid;
+	knh_class_t req_bcid = ctx->share->ClassTable[reqc].bcid;
 	if(req_bcid != CLASS_Int && req_bcid != CLASS_Float) {
 		req_bcid = knh_bytes_guessNUMcid(ctx, t);
 		reqc = req_bcid;
@@ -771,7 +771,7 @@ int knh_TokenNUM_typing(Ctx *ctx, Token *o, NameSpace *ns, knh_class_t reqc)
 		}
 	}
 	else { /* if(req_bcid == CLASS_Int) */
-		knh_integer_t n = 0;
+		knh_int_t n = 0;
 		if(!knh_bytes_parseinteger(t, &n)) {
 			knh_Token_perror(ctx, o, KMSG_WNUMOVERFLOW);
 			knh_perrata(ctx, SP(o)->fileid, SP(o)->line, (char*)t.buf, "0");
@@ -840,7 +840,7 @@ int knh_Token_typing(Ctx *ctx, Token *tk, Asm *abr, NameSpace *ns, knh_type_t re
 	case TT_STR:
 		KNH_ASSERT(IS_String(DP(tk)->data));
 		knh_Token_toCONST(tk);
-//		if(ctx->tClass[reqc].bcid == CLASS_String) {
+//		if(ctx->share->ClassTable[reqc].bcid == CLASS_String) {
 //			DP(o)->type = reqc;
 //		}
 		return 1;
@@ -921,7 +921,7 @@ static Object *TERMs_value(Ctx *ctx, Stmt *stmt, size_t n, knh_type_t type)
 		if(SP(tk)->tt == TT_CONST) return DP(tk)->data;
 		if(SP(tk)->tt == TT_ASIS) {
 			return IS_NNTYPE(type) ?
-					konoha_getClassDefaultValue(ctx, CLASS_type(type)) : KNH_NULL;
+					konoha_geClassTableDefaultValue(ctx, CLASS_type(type)) : KNH_NULL;
 		}
 	}
 	return KNH_NULL;
@@ -946,7 +946,7 @@ static int TERMs_isCLASSID(Stmt *stmt, size_t n)
 /* ------------------------------------------------------------------------ */
 
 #define _TERMs_getcid(stmt, n)    CLASS_type(TERMs_gettype(stmt, n))
-#define _TERMs_getbcid(stmt, n)   ctx->tClass[TERMs_getcid(stmt,n)].bcid
+#define _TERMs_getbcid(stmt, n)   ctx->share->ClassTable[TERMs_getcid(stmt,n)].bcid
 
 knh_type_t TERMs_gettype(Stmt *stmt, size_t n)
 {
@@ -1105,7 +1105,7 @@ knh_bool_t knh_Asm_existsName(Ctx *ctx, Asm *abr, knh_fieldn_t fnq)
 static
 Object *knh_StmtDECL_value(Ctx *ctx, knh_type_t type)
 {
-	return IS_NNTYPE(type) ? konoha_getClassDefaultValue(ctx, CLASS_type(type)) : KNH_NULL;
+	return IS_NNTYPE(type) ? konoha_geClassTableDefaultValue(ctx, CLASS_type(type)) : KNH_NULL;
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1223,7 +1223,7 @@ int TERMs_isCONSTNAME(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, NameSpace *ns)
 		for(i = 0; i < cname.len; i++) {
 			if(islower(cname.buf[i])) return 0;
 		}
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, cname);
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, cname);
 		return (cid == CLASS_unknown);
 	}
 	return 0;
@@ -1278,7 +1278,7 @@ Term *knh_StmtLET_declCONST(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, int l
 		}
 		else {
 			knh_bytes_t fn = knh_bytes_first(cn, dotidx);
-			knh_class_t cid = knh_NameSpace_getClass(ctx, ns, fn);
+			knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, fn);
 			if(cid == CLASS_unknown) {
 				pe = KMSG_UCLASSN; goto L_PERROR;
 			}
@@ -1437,7 +1437,7 @@ void KNH_BOX(Ctx *ctx, knh_sfp_t *sfp, knh_type_t type)
 {
 	knh_class_t cid = CLASS_type(type);
 	KNH_ASSERT_cid(cid);
-	knh_class_t bcid = ctx->tClass[cid].bcid;
+	knh_class_t bcid = ctx->share->ClassTable[cid].bcid;
 	if(bcid == CLASS_Int || bcid == CLASS_Float || bcid == CLASS_Boolean) {
 		if(IS_NNTYPE(type) || IS_NOTNULL(sfp[0].o)) {
 			KNH_SETv(ctx, sfp[0].o, knh_boxing(ctx, sfp, cid));
@@ -1544,7 +1544,7 @@ static int knh_type_isClosure(Ctx *ctx, knh_type_t type)
 {
 	knh_class_t cid = CLASS_type(type);
 	KNH_ASSERT_cid(cid);
-	return (ctx->tClass[cid].bcid == CLASS_Closure);
+	return (ctx->share->ClassTable[cid].bcid == CLASS_Closure);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -1622,13 +1622,13 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		return TM(stmt);
 	}
 
-	knh_Stmt_setType(ctx, stmt, ctx->tClass[cid].r0);
+	knh_Stmt_setType(ctx, stmt, ctx->share->ClassTable[cid].r0);
 
-	if(ctx->tClass[cid].p1 != TYPE_void) {
+	if(ctx->share->ClassTable[cid].p1 != TYPE_void) {
 		if(!(DP(stmt)->size > 2)) {
-			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->tClass[cid].p1)));
+			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->share->ClassTable[cid].p1)));
 		}
-		if(!TERMs_typing(ctx, stmt, 2, abr, ns, ctx->tClass[cid].p1, TCHECK_)) {
+		if(!TERMs_typing(ctx, stmt, 2, abr, ns, ctx->share->ClassTable[cid].p1, TCHECK_)) {
 			return NULL;
 		}
 	}
@@ -1637,11 +1637,11 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		return TM(stmt);
 	}
 
-	if(ctx->tClass[cid].p2 != TYPE_void) {
+	if(ctx->share->ClassTable[cid].p2 != TYPE_void) {
 		if(!(DP(stmt)->size > 3)) {
-			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->tClass[cid].p2)));
+			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->share->ClassTable[cid].p2)));
 		}
-		if(!TERMs_typing(ctx, stmt, 3, abr, ns, ctx->tClass[cid].p2, TCHECK_)) {
+		if(!TERMs_typing(ctx, stmt, 3, abr, ns, ctx->share->ClassTable[cid].p2, TCHECK_)) {
 			return NULL;
 		}
 	}
@@ -1650,11 +1650,11 @@ Term *knh_StmtINVOKE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		return TM(stmt);
 	}
 
-	if(ctx->tClass[cid].p3 != TYPE_void) {
+	if(ctx->share->ClassTable[cid].p3 != TYPE_void) {
 		if(!(DP(stmt)->size > 4)) {
-			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->tClass[cid].p3)));
+			knh_Stmt_add(ctx, stmt, UP(new_TokenNULL(ctx, FL(stmt), ctx->share->ClassTable[cid].p3)));
 		}
-		if(!TERMs_typing(ctx, stmt, 4, abr, ns, ctx->tClass[cid].p3, TCHECK_)) {
+		if(!TERMs_typing(ctx, stmt, 4, abr, ns, ctx->share->ClassTable[cid].p3, TCHECK_)) {
 			return NULL;
 		}
 		DP(stmt)->size = 5;
@@ -1721,7 +1721,7 @@ Term *knh_StmtCALLBASE_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh
 	else if(mn == METHODN_super || mn == METHODN_this) {
 		knh_class_t mtd_cid = CLASS_type(DP(abr)->vars[0].type);
 		if(mn == METHODN_super) {
-			KNH_ASSERT_cid(mtd_cid); mtd_cid = ctx->tClass[mtd_cid].supcid;
+			KNH_ASSERT_cid(mtd_cid); mtd_cid = ctx->share->ClassTable[mtd_cid].supcid;
 		}
 		Token *mtk = DP(stmt)->tokens[0]; /* change */
 		SP(mtk)->tt = TT_MN;
@@ -1923,7 +1923,7 @@ Term *knh_StmtNEW_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_clas
 
 	if(mtd_cid == CLASS_Array) {
 		knh_class_t reqc = CLASS_type(reqt); KNH_ASSERT_cid(reqc);
-		if(ctx->tClass[reqc].bcid == CLASS_Array) {
+		if(ctx->share->ClassTable[reqc].bcid == CLASS_Array) {
 			mtd_cid = reqc;
 		}
 		else if(reqc == CLASS_Any && mn == METHODN_new__init && DP(stmt)->size > 2) {
@@ -1999,8 +1999,8 @@ knh_class_t knh_StmtOPADD_basecid(Ctx *ctx, Stmt *stmt)
 	if(cid1 == CLASS_Any || cid2 == CLASS_Any) return CLASS_Any;
 	if(cid1 == cid2) return cid1;
 
-	knh_class_t bcid1 = ctx->tClass[cid1].bcid;
-	knh_class_t bcid2 = ctx->tClass[cid2].bcid;
+	knh_class_t bcid1 = ctx->share->ClassTable[cid1].bcid;
+	knh_class_t bcid2 = ctx->share->ClassTable[cid2].bcid;
 
 	if(bcid1 == bcid2) return bcid1;
 
@@ -2024,8 +2024,8 @@ knh_class_t knh_StmtOPEQ_basecid(Ctx *ctx, Stmt *stmt)
 	if(cid1 == cid2) return cid1;
 	if(cid1 == CLASS_Any || cid2 == CLASS_Any) return CLASS_Any;
 
-	knh_class_t bcid1 = ctx->tClass[cid1].bcid;
-	knh_class_t bcid2 = ctx->tClass[cid2].bcid;
+	knh_class_t bcid1 = ctx->share->ClassTable[cid1].bcid;
+	knh_class_t bcid2 = ctx->share->ClassTable[cid2].bcid;
 
 	if(bcid1 == cid2) return bcid1;
 	if(bcid2 == cid1) return bcid2;
@@ -2248,7 +2248,7 @@ Term *knh_StmtMAPCAST_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns, knh_
 
 	if(TERMs_isNULL(stmt, 1)) {
 		if(knh_Token_isNotNullType(tk)) {
-			knh_Token_setCONST(ctx, DP(stmt)->tokens[1], konoha_getClassDefaultValue(ctx, mprcid));
+			knh_Token_setCONST(ctx, DP(stmt)->tokens[1], konoha_geClassTableDefaultValue(ctx, mprcid));
 		}
 		return DP(stmt)->terms[1];
 	}
@@ -2503,7 +2503,7 @@ int TERMs_typecheck(Ctx *ctx, Stmt *stmt, size_t n, Asm *abr, knh_type_t reqt, i
 
 	if(vart == reqt || reqc == CLASS_Any || knh_class_instanceof(ctx, varc, reqc)) return 1;
 
-	if(mode == TITERCONV_ && ctx->tClass[varc].bcid == CLASS_Iterator) return 1;
+	if(mode == TITERCONV_ && ctx->share->ClassTable[varc].bcid == CLASS_Iterator) return 1;
 
 	if(varc == CLASS_Any ||
 		(varc == CLASS_Float && reqc == CLASS_Int) ||
@@ -2675,10 +2675,10 @@ knh_fieldn_t knh_tName_local(Ctx *ctx, const char *fmt, int level)
 	char bufn[40];
 	knh_snprintf(bufn, sizeof(bufn), fmt, level);
 	knh_bytes_t tname = B(bufn);
-	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->tfieldnDictIdx, tname);
+	knh_index_t idx = knh_DictIdx_index(ctx, DP(ctx->sys)->FieldNameDictIdx, tname);
 	if(idx == -1) {
 		String *s = new_String(ctx, tname, NULL);
-		idx = knh_DictIdx_add__fast(ctx, DP(ctx->sys)->tfieldnDictIdx, s);
+		idx = knh_DictIdx_add__fast(ctx, DP(ctx->sys)->FieldNameDictIdx, s);
 	}
 	return (knh_fieldn_t)idx;
 }
@@ -2707,9 +2707,9 @@ Term *knh_StmtFOREACH_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 				}
 			}
 			knh_class_t itrcid = TERMs_getcid(stmt, FOREACH_iter);
-			type = NNTYPE_cid(ctx->tClass[itrcid].p1);
+			type = NNTYPE_cid(ctx->share->ClassTable[itrcid].p1);
 			type = knh_Asm_typeinfer(ctx, abr, type, FIELDN(fn));
-			knh_Asm_declareVariable(ctx, abr, 0, type, fn, konoha_getClassDefaultValue(ctx, CLASS_type(type)));
+			knh_Asm_declareVariable(ctx, abr, 0, type, fn, konoha_geClassTableDefaultValue(ctx, CLASS_type(type)));
 			if(!TERMs_typing(ctx, stmt, FOREACH_name, abr, ns, type, TCHECK_)) {
 				return NULL;
 			}
@@ -2920,7 +2920,7 @@ knh_class_t knh_StmtMETHOD_class(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns,
 			name = knh_bytes_first(name, idx);
 		}
 
-		knh_class_t cid = knh_NameSpace_getClass(ctx, ns, name);
+		knh_class_t cid = knh_NameSpace_geClassTable(ctx, ns, name);
 		if(cid == CLASS_unknown) {
 			knh_Asm_perror(ctx, abr, KMSG_UCLASSN, (char*)name.buf);
 			cid = DP(abr)->this_cid;
@@ -3009,30 +3009,37 @@ int knh_Stmt_initParams(Ctx *ctx, Stmt *pstmt, Asm *abr, NameSpace *ns, int leve
 static
 MethodField *knh_tMethodField_find(Ctx *ctx, Asm *abr, knh_type_t rztype, size_t mfsize)
 {
-	int i, n = 0, size = knh_tMethodField_size;
-	L_CONTINUE:;
-	while(n < size) {
-		MethodField *mf = knh_tMethodField(ctx, n);
-		if(mfsize != mf->size) {
-			n++;
-			continue;
+	knh_hcode_t h = rztype;
+	size_t i;
+	for(i = 1; i < mfsize; i++) {
+		knh_type_t vtype = DP(abr)->vars[i].type;
+		if(IS_NOTNULL(DP(abr)->vars[i].value)) {
+			vtype = CLASS_type(vtype);
 		}
-		if(mf->params[0].type != rztype) {
-			n++;
-			continue;
-		}
-		for(i = 1; i < mfsize; i++) {
-			knh_type_t vtype = DP(abr)->vars[i].type;
-			if(IS_NOTNULL(DP(abr)->vars[i].value)) {
-				vtype = CLASS_type(vtype);
+		h = knh_mparam_hcode(h, vtype, DP(abr)->vars[i].fn);
+	}
+	HashMap *hmap = DP(ctx->sys)->MethodFieldHashMap;
+	if(IS_NOTNULL(hmap)) {
+		KNH_LOCK(ctx, LOCK_SYSTBL, NULL);
+		MethodField *mf = (MethodField*)knh_HashMap_get__hcode(ctx, hmap, h);
+		KNH_UNLOCK(ctx, LOCK_SYSTBL, NULL);
+		if(IS_MethodField(mf)) {
+			if(mf->rtype != rztype || mf->psize + 1 != mfsize) {
+				return NULL;
 			}
-			if(mf->params[i].type != vtype) {
-				n++;
-				goto L_CONTINUE;
+			for(i = 1; i < mfsize; i++) {
+				knh_mparam_t p = knh_MethodField_param(mf, i-1);
+				knh_type_t vtype = DP(abr)->vars[i].type;
+				if(IS_NOTNULL(DP(abr)->vars[i].value)) {
+					vtype = CLASS_type(vtype);
+				}
+				if(vtype != p.type || p.fn != DP(abr)->vars[i].fn) {
+					return NULL;
+				}
 			}
+			DBG2_P("Found Predefined MethodField %p", mf);
+			return mf;
 		}
-		DEBUG3("Found defined method field");
-		return mf;
 	}
 	return NULL;
 }
@@ -3075,7 +3082,7 @@ static
 char *knh_format_funcname(Ctx *ctx, char *buf, size_t bufsiz, knh_class_t cid, knh_methodn_t mn)
 {
 	KNH_ASSERT_cid(cid);
-	char *cname = knh_String_tochar(ctx->tClass[cid].sname);
+	char *cname = knh_String_tochar(ctx->share->ClassTable[cid].sname);
 	if(METHODN_IS_MOVTEXT(mn)) {
 		knh_snprintf(buf, bufsiz, "%s__%s", cname, FIELDN(METHODN_TOFIELDN(mn)));
 		return buf;
@@ -3146,19 +3153,17 @@ Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 		size_t i, mfsize = DP(abr)->vars_size;
 		MethodField *mf = knh_tMethodField_find(ctx, abr, rztype, mfsize);
 		if(mf == NULL) {
-			mf = new_MethodField(ctx, mfsize);
-			mf->params[0].type = rztype;
-			mf->params[0].fn   = FIELDN_return;
+			size_t psize = mfsize - 1;
+			mf = new_MethodField(ctx, rztype, psize);
 			for(i = 1; i < mfsize; i++) {
 				if(IS_NOTNULL(DP(abr)->vars[i].value)) {
-					mf->params[i].type = CLASS_type(DP(abr)->vars[i].type);
+					knh_MethodField_set(mf, i - 1, CLASS_type(DP(abr)->vars[i].type), DP(abr)->vars[i].fn);
 				}
 				else {
-					mf->params[i].type = DP(abr)->vars[i].type;
+					knh_MethodField_set(mf, i - 1, DP(abr)->vars[i].type, DP(abr)->vars[i].fn);
 				}
-				mf->params[i].fn = DP(abr)->vars[i].fn;
 			}
-			knh_tMethodField_add(ctx, mf);
+			konoha_addMethodFieldTable(ctx, mf);
 		}
 		mtd = new_Method(ctx, flag, mtd_cid, mn, NULL);
 		KNH_SETv(ctx, DP(mtd)->mf, mf);
@@ -3185,16 +3190,16 @@ Term * knh_StmtMETHOD_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 			return NULL;
 		}
 
-		if(mfsize != mf->size) {
+		if(mfsize != mf->psize+1) {
 			pe = KMSG_DIFFPSIZE; goto L_PERROR;
 		}
 
-		if(mf->params[0].type != rztype) {
+		if(mf->rtype != rztype) {
 			pe = KMSG_DIFFRTYPE; goto L_PERROR;
 		}
 
 		for(i = 1; i < mfsize; i++) {
-			knh_type_t ptype = mf->params[i].type;
+			knh_type_t ptype = knh_MethodField_pztype(mf, i - 1);
 			knh_type_t vtype = DP(abr)->vars[i].type;
 			if(IS_NOTNULL(DP(abr)->vars[i].value)) {
 				vtype = CLASS_type(vtype);
@@ -3243,12 +3248,12 @@ Term *knh_StmtFORMAT_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 /* ------------------------------------------------------------------------ */
 
 static
-void knh_Asm_initClassField(Ctx *ctx, Asm *abr, knh_class_t cid)
+void knh_Asm_iniClassTableField(Ctx *ctx, Asm *abr, knh_class_t cid)
 {
 	DP(abr)->flag = 0;
 	DP(abr)->this_cid = cid;
 	DP(abr)->level = 0;
-	knh_int_t i;
+	knh_intptr_t i;
 	DP(abr)->vars_size = 0;
 	for(i = 0; i < KONOHA_LOCALSIZE; i++) {
 		DP(abr)->vars[i].flag  = 0;
@@ -3264,7 +3269,7 @@ void knh_Asm_initClassField(Ctx *ctx, Asm *abr, knh_class_t cid)
 static
 void knh_Asm_declareClassField(Ctx *ctx, Asm *abr, knh_class_t cid)
 {
-	knh_tClass_t *TC = (knh_tClass_t*)(&ctx->tClass[cid]);
+	knh_ClassTable_t *TC = (knh_ClassTable_t*)(&ctx->share->ClassTable[cid]);
 	DEBUG3_ASSERT(IS_ClassStruct(TC->cstruct));
 	DEBUG3_ASSERT((TC->cstruct)->fields == NULL);
 	{
@@ -3283,7 +3288,7 @@ void knh_Asm_declareClassField(Ctx *ctx, Asm *abr, knh_class_t cid)
 		TC->sid = BSIZE_TOSID(fsize);
 		TC->bsize = fsize + TC->offset;
 		TC->size = sizeof(Object*) * TC->bsize;
-		knh_NameSpace_setClass(ctx, knh_rootNameSpace, TC->lname, cid);
+		knh_NameSpace_seClassTable(ctx, knh_rootNameSpace, TC->lname, cid);
 		DBG2_({
 			DBG2_P("HERE IS DEFINED STRUCT");
 			knh_cfield_dump(ctx, cf, 0, fsize, KNH_STDOUT);
@@ -3298,7 +3303,7 @@ Term *knh_StmtCLASS_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	knh_class_t prev_cid = DP(abr)->this_cid;
 	knh_class_t this_cid = DP(StmtCLASS_class(stmt))->cid;
 
-	knh_Asm_initClassField(ctx, abr, this_cid);
+	knh_Asm_iniClassTableField(ctx, abr, this_cid);
 
 	Stmt *instmt = StmtCLASS_instmt(stmt);
 	while(IS_Stmt(instmt)) {
@@ -3316,7 +3321,7 @@ Term *knh_StmtCLASS_typing(Ctx *ctx, Stmt *stmt, Asm *abr, NameSpace *ns)
 	}
 	knh_Asm_declareClassField(ctx, abr, this_cid);
 
-	knh_Asm_initClassField(ctx, abr, this_cid);
+	knh_Asm_iniClassTableField(ctx, abr, this_cid);
 	instmt = StmtCLASS_instmt(stmt);
 	while(IS_Stmt(instmt)) {
 		DP(abr)->line = SP(instmt)->line;
