@@ -56,6 +56,34 @@ extern "C" {
 /* ======================================================================== */
 /* [TLS] */
 
+knh_thread_t knh_thread_self()
+{
+#ifdef KNH_USING_PTHREAD
+#undef KNH_USING_NOTHREAD
+	return pthread_self();
+#endif
+#ifdef KNH_USING_NOTHREAD
+	return 0;
+#endif
+}
+
+/* ------------------------------------------------------------------------ */
+
+int thread_create(knh_thread_t *thread, void *attr, void *(*start_routine)(void *), void * arg)
+{
+#ifdef KNH_USING_PTHREAD
+#undef KNH_USING_NOTHREAD
+	return pthread_create(thread, attr, start_rutine, arg);
+#endif
+#ifdef KNH_USING_NOTHREAD
+	return -1;
+#endif
+}
+
+/* ======================================================================== */
+/* [TLS] */
+
+
 #ifdef KNH_USING_PTHREAD
 static void destr(void *data)
 {
