@@ -142,7 +142,7 @@ knh_Object_t *new_UnusedObject(Ctx *ctx)
 	ctx->share->ObjectPageTableSize += 1;
 	KNH_UNLOCK(ctx, LOCK_MEMORY, NULL);
 
-	void *t = KNH_MALLOC(ctx, SIZEOF_OBJECTPAGE);
+	char *t = KNH_MALLOC(ctx, SIZEOF_OBJECTPAGE);
 	knh_bzero(t, SIZEOF_OBJECTPAGE);
 	ctx->share->ObjectPageTable[tindex].ctxid = ctx->ctxid;
 	ctx->share->ObjectPageTable[tindex].thead = t;
@@ -150,11 +150,11 @@ knh_Object_t *new_UnusedObject(Ctx *ctx)
 		t = (void*)((((knh_uintptr_t)t / KONOHA_PAGESIZE) + 1) * KONOHA_PAGESIZE);
 		KNH_ASSERT((knh_uintptr_t)t % KONOHA_PAGESIZE == 0);
 	}
-	void *h = t, *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
+	char *h = t, *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
 	int cnt = 0;
 	while(t + KONOHA_PAGESIZE < max) {
 		int i;
-		knh_Object_t *o = t;
+		knh_Object_t *o = (knh_Object_t*)t;
 		for(i = 1; i < KONOHA_PAGESIZE / sizeof(knh_Object_t) - 1; i++) {
 			//o[i].h.magic = 0;
 			o[i].ref = &(o[i+1]);
@@ -468,15 +468,15 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 {
 	int tindex, size = (int)(ctx->share->ObjectPageTableSize);
 
-	DBG_P("*** STARTING GC (+%d) ***", (int)(BSHIFT));
+	DBG_P("** GC - Starting (used %d Kb) ***", (int)ctx->stat->usedMemorySize/1024);
 	for(tindex = 0; tindex < size; tindex++) {
-		void *t = ctx->share->ObjectPageTable[tindex].thead;
+		char *t = ctx->share->ObjectPageTable[tindex].thead;
 
 		if((knh_uintptr_t)t % KONOHA_PAGESIZE != 0) {
-			t = (void*)((((knh_uintptr_t)t / KONOHA_PAGESIZE) + 1) * KONOHA_PAGESIZE);
+			t = (char*)((((knh_uintptr_t)t / KONOHA_PAGESIZE) + 1) * KONOHA_PAGESIZE);
 			KNH_ASSERT((knh_uintptr_t)t % KONOHA_PAGESIZE == 0);
 		}
-		void *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
+		char *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
 		while(t + KONOHA_PAGESIZE < max) {
 			knh_uintptr_t *b = (knh_uintptr_t*)t;
 			int i;
@@ -487,25 +487,23 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 		}
 	}
 
-	DBG_P("***** Marking .. ******");
 	DBG_DISABLE_FREE();
 	mcount = 0;
 	konoha_traverse(ctx, knh_Object_mark1);
 	DBG_ENABLE_FREE();
-	DBG_P("Marked %d/%d objects", mcount, ctx->stat->usedObjectSize);
+	DBG_P("** GC - Marked %d/%d object(s)", (int)mcount, (int)ctx->stat->usedObjectSize);
 
-	DBG_P("***** Sweeping .. ******");
 	size_t cnt = 0;
 	knh_ftraverse fsweep = ctx->fsweep;
 	((Context*)ctx)->fsweep = knh_Object_finalSweep;
 	for(tindex = 0; tindex < size; tindex++) {
-		void *t = ctx->share->ObjectPageTable[tindex].thead;
+		char *t = ctx->share->ObjectPageTable[tindex].thead;
 
 		if((knh_uintptr_t)t % KONOHA_PAGESIZE != 0) {
-			t = (void*)((((knh_uintptr_t)t / KONOHA_PAGESIZE) + 1) * KONOHA_PAGESIZE);
+			t = (char*)((((knh_uintptr_t)t / KONOHA_PAGESIZE) + 1) * KONOHA_PAGESIZE);
 			KNH_ASSERT((knh_uintptr_t)t % KONOHA_PAGESIZE == 0);
 		}
-		void *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
+		char *max = ctx->share->ObjectPageTable[tindex].thead + SIZEOF_OBJECTPAGE;
 
 		while(t + KONOHA_PAGESIZE < max) {
 			knh_uintptr_t *b = ((knh_uintptr_t*)t) + BSHIFT;
@@ -514,19 +512,19 @@ METHOD knh__System_gc(Ctx *ctx, knh_sfp_t *sfp)
 				int x = i/(sizeof(knh_uintptr_t)*8);
 				knh_uintptr_t mask = 1 << (i % (sizeof(knh_uintptr_t)*8));
 				if((b[x] & mask) == mask) continue;
-				knh_Object_t *o = t + i;
+				knh_Object_t *o = ((Object*)t) + i;
 				DBG2_ASSERT(!knh_isFastMallocMemory((void*)o));
-				if(o->h.magic != KNH_OBJECT_MAGIC) continue;
 				knh_Object_RCset(o, 0);
-				DBG2_P("i=%d, x=%d, o=%p, cid=%s(%d)", i, x, o, CLASSN(o->h.bcid), o->h.bcid);
-				//knh_Object_free(ctx, o);
+				if(o->h.magic == 0) continue;
+				//DBG2_P("i=%d, x=%d, o=%p, magic=%d, cid=%s(%d)", i, x, o, o->h.magic, CLASSN(o->h.bcid), o->h.bcid);
+				knh_Object_free(ctx, o);
 				cnt++;
 			}
 			t += KONOHA_PAGESIZE;
 		}
 	}
 	((Context*)ctx)->fsweep = fsweep;
-	DBG_P("**** Collected %d object(s) ****", (int)cnt);
+	DBG_P("** GC - Collected %d/%d object(s) used=%d Kbytes", (int)cnt, (int)ctx->stat->usedObjectSize, (int)ctx->stat->usedMemorySize/1024);
 }
 
 /* ------------------------------------------------------------------------ */
@@ -536,8 +534,8 @@ void knh_System_gc(Ctx *ctx)
 	knh__System_gc(ctx, NULL);
 }
 
-
 /* ------------------------------------------------------------------------ */
+/* [RCGC] */
 
 void knh_Object_RCsweep(Ctx *ctx, Object *o)
 {
@@ -554,29 +552,7 @@ knh_ftraverse konoha_getDefaultSweepFunc()
 	return knh_Object_RCsweep;
 }
 
-
-
-///* ------------------------------------------------------------------------ */
-//
-//#define P11 ((knh_uint32_t)3)
-//#define P10 ((knh_uint32_t)2)
-//#define P01 ((knh_uint32_t)1)
-//
-//static const knh_uint32_t mask11[] = {
-//	P11 << 30, P11 << 28, P11 << 26, P11 << 24,
-//	P11 << 22, P11 << 20, P11 << 18, P11 << 16,
-//	p11 << 14, P11 << 12, P11 << 10, P11 << 8,
-//	P11 << 6,  P11 << 4,  P11 << 2,  P11 << 0
-//};
-//
-///* ------------------------------------------------------------------------ */
-//
-//void bitmap_unused(knh_uint32_t bitmap[256], size_t n)
-//{
-//	knh_uint32_t b = bitmap[n / 16];
-//	bitmap[n / 16] = ~mask11[n % 16];
-//}
-
+/* ------------------------------------------------------------------------ */
 
 #ifdef __cplusplus
 }
